@@ -2,7 +2,7 @@ from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annot
 from mindor.dsl.schema.workflow import JobConfig
 from mindor.dsl.schema.component import ComponentConfig
 from mindor.core.component import ComponentGlobalConfigs
-from .base import Job, JobRegistry
+from .base import Job, JobRegistry, RoutingTarget
 
 def create_job(id: str, config: JobConfig, global_configs: ComponentGlobalConfigs) -> Job:
     if not JobRegistry:
