@@ -2,8 +2,9 @@ from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annot
 from dataclasses import dataclass, asdict
 from pydantic import BaseModel
 from mindor.dsl.schema.workflow import WorkflowConfig, WorkflowVariableConfig, WorkflowVariableGroupConfig
-from mindor.dsl.schema.job import ActionJobConfig
+from mindor.dsl.schema.job import ActionJobConfig, OutputJobConfig
 from mindor.dsl.schema.component import ComponentConfig, ComponentType
+from mindor.dsl.schema.action import ActionConfig
 import re, json
 
 @dataclass
@@ -193,10 +194,10 @@ class WorkflowVariableResolver:
 
 class WorkflowInputVariableResolver(WorkflowVariableResolver):
     def resolve(self, workflow: WorkflowConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[WorkflowVariableConfig]:
-        return self._to_variable_config_list(self._resolve(workflow, workflows, components))
+        return self._to_variable_config_list(self._resolve_workflow(workflow, workflows, components))
     
-    def _resolve(self, workflow: WorkflowConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[Union[WorkflowVariable, WorkflowVariableGroup]]:
-        variables: List[Union[WorkflowVariable, WorkflowVariableGroup]] = []
+    def _resolve_workflow(self, workflow: WorkflowConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[WorkflowVariable]:
+        variables: List[WorkflowVariable] = []
 
         for job in workflow.jobs.values():
             if isinstance(job, ActionJobConfig) and (not job.input or job.input == "${input}"):
@@ -206,37 +207,45 @@ class WorkflowInputVariableResolver(WorkflowVariableResolver):
                     if component:
                         action = component.actions[action_id] if action_id in component.actions else None
                         if action:
-                            if component.type == ComponentType.WORKFLOW:
-                                sub_workflow_id = action.workflow or "__default__"
-                                sub_workflow = workflows[sub_workflow_id] if sub_workflow_id in workflows else None
-                                if sub_workflow:
-                                    variables.extend(self._resolve(sub_workflow, workflows, components))
-                            else:
-                                variables.extend(self._enumerate_input_variables(action, "input", internal=True))
+                            variables.extend(self._resolve_component(component, action, workflows, components))
                 else:
                     action = job.component.actions[action_id] if action_id in job.component.actions else None
                     if action:
-                        variables.extend(self._enumerate_input_variables(action, "input", internal=True))
+                        variables.extend(self._resolve_component(job.component, action, workflows, components))
             else:
                 variables.extend(self._enumerate_input_variables(job, "input"))
 
         return variables
 
+    def _resolve_component(self, component: ComponentConfig, action: ActionConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[WorkflowVariable]:
+        variables: List[WorkflowVariable] = []
+     
+        if component.type == ComponentType.WORKFLOW:
+            workflow_id = action.workflow or "__default__"
+            workflow = workflows[workflow_id] if workflow_id in workflows else None
+            if workflow:
+                variables.extend(self._resolve_workflow(workflow, workflows, components))
+        else:
+            variables.extend(self._enumerate_input_variables(action, "input", internal=True))
+
+        return variables
+
 class WorkflowOutputVariableResolver(WorkflowVariableResolver):
     def resolve(self, workflow: WorkflowConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[WorkflowVariableConfig]:
-        return self._to_variable_config_list(self._resolve(workflow, workflows, components))
+        return self._to_variable_config_list(self._resolve_workflow(workflow, workflows, components))
 
-    def _resolve(self, workflow: WorkflowConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[Union[WorkflowVariableConfig, WorkflowVariableGroupConfig]]:
+    def _resolve_workflow(self, workflow: WorkflowConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig], internal: bool = False) -> List[Union[WorkflowVariableConfig, WorkflowVariableGroupConfig]]:
         variables: List[Union[WorkflowVariable, WorkflowVariableGroup]] = []
 
+        routing_job_ids: Set[str] = { job_id for job in workflow.jobs.values() for job_id in job.get_routing_jobs() }
         for job_id, job in workflow.jobs.items():
             if not self._is_terminal_job(workflow, job_id):
                 continue
 
             job_variables: List[WorkflowVariable] = variables
-            repeat_count: int = job.repeat_count if isinstance(job.repeat_count, int) else 0
+            repeat_count: int = job.repeat_count if isinstance(job, ActionJobConfig) and isinstance(job.repeat_count, int) else 0
 
-            if repeat_count != 1:
+            if repeat_count > 1:
                 variables.append(WorkflowVariableGroup(variables=(job_variables := []), repeat_count=repeat_count))
 
             if isinstance(job, ActionJobConfig) and (not job.output or job.output == "${output}"):
@@ -246,19 +255,27 @@ class WorkflowOutputVariableResolver(WorkflowVariableResolver):
                     if component:
                         action = component.actions[action_id] if action_id in component.actions else None
                         if action:
-                            if component.type == ComponentType.WORKFLOW:
-                                sub_workflow_id = action.workflow or "__default__"
-                                sub_workflow = workflows[sub_workflow_id] if sub_workflow_id in workflows else None
-                                if sub_workflow:
-                                    variables.extend(self._resolve(sub_workflow, workflows, components))
-                            else:
-                                job_variables.extend(self._enumerate_output_variables(None, action.output, internal=True))
+                            job_variables.extend(self._resolve_component(component, action, workflows, components))           
                 else:
                     action = job.component.actions[action_id] if action_id in job.component.actions else None
                     if action:
-                        job_variables.extend(self._enumerate_output_variables(None, action.output, internal=True))
+                        job_variables.extend(self._resolve_component(component, action, workflows, components))           
             else:
-                job_variables.extend(self._enumerate_output_variables(None, job.output))
+                if isinstance(job, OutputJobConfig):
+                    job_variables.extend(self._enumerate_output_variables(None, job.output, internal=internal))
+
+        return variables
+
+    def _resolve_component(self, component: ComponentConfig, action: ActionConfig, workflows: Dict[str, WorkflowConfig], components: Dict[str, ComponentConfig]) -> List[Union[WorkflowVariable, WorkflowVariableGroup]]:
+        variables: List[Union[WorkflowVariable, WorkflowVariableGroup]] = []
+
+        if component.type == ComponentType.WORKFLOW:
+            workflow_id = action.workflow or "__default__"
+            workflow = workflows[workflow_id] if workflow_id in workflows else None
+            if workflow:
+                variables.extend(self._resolve_workflow(workflow, workflows, components, internal=True))
+        else:
+            variables.extend(self._enumerate_output_variables(None, action.output, internal=True))
 
         return variables
 
@@ -267,7 +284,7 @@ class WorkflowOutputVariableResolver(WorkflowVariableResolver):
 
 class WorkflowSchema:
     def __init__(
-        self, 
+        self,
         name: Optional[str], 
         title: Optional[str], 
         description: Optional[str], 
