@@ -2,5 +2,5 @@ from typing import Type, Union, Literal, Optional, Dict, List, Tuple, Set, Annot
 from pydantic import BaseModel, Field
 from .types import RuntimeType
 
-class CommonRumtimeConfig(BaseModel):
+class CommonRuntimeConfig(BaseModel):
     type: RuntimeType = Field(..., description="")
